SLDSIcons class
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- account → const IconData
- account_info → const IconData
- action_list_component → const IconData
- activation_target → const IconData
- activations → const IconData
- activity → const IconData
- ad_set → const IconData
- add → const IconData
- add_contact → const IconData
- add_file → const IconData
- add_photo_video → const IconData
- add_relationship → const IconData
- address → const IconData
- adduser → const IconData
- adjust_value → const IconData
- advanced_function → const IconData
- advertising → const IconData
- agent_home → const IconData
- agent_session → const IconData
- aggregation_policy → const IconData
- ai → const IconData
- ai_accelerator_card → const IconData
- alert → const IconData
- all → const IconData
- anchor → const IconData
- animal_and_nature → const IconData
- announcement → const IconData
- answer → const IconData
- answer_best → const IconData
- answer_private → const IconData
- answer_public → const IconData
- answered_twice → const IconData
- anywhere_alert → const IconData
- anywhere_chat → const IconData
- apex → const IconData
- apex_plugin → const IconData
- app → const IconData
- approval → const IconData
- apps → const IconData
- apps_admin → const IconData
- archive → const IconData
- arrow_bottom → const IconData
- arrow_left → const IconData
- arrow_right → const IconData
- arrow_top → const IconData
- arrowdown → const IconData
- arrowup → const IconData
- article → const IconData
- asset_action → const IconData
- asset_action_source → const IconData
- asset_audit → const IconData
- asset_downtime_period → const IconData
- asset_hierarchy → const IconData
- asset_object → const IconData
- asset_relationship → const IconData
- asset_state_period → const IconData
- asset_warranty → const IconData
- assigned_resource → const IconData
- assignment → const IconData
- attach → const IconData
- attachment → const IconData
- audio → const IconData
- automate → const IconData
- avatar → const IconData
- avatar_loading → const IconData
- away → const IconData
- back → const IconData
- ban → const IconData
- block_visitor → const IconData
- bold → const IconData
- bookmark → const IconData
- bookmark_alt → const IconData
- bot → const IconData
- bot_training → const IconData
- bottom_align → const IconData
- box_notes → const IconData
- branch_merge → const IconData
- brand → const IconData
- broadcast → const IconData
- brush → const IconData
- bucket → const IconData
- budget → const IconData
- budget_allocation → const IconData
- budget_category_value → const IconData
- budget_period → const IconData
- bug → const IconData
- builder → const IconData
- bundle_config → const IconData
- bundle_policy → const IconData
- business_hours → const IconData
- buyer_account → const IconData
- buyer_group → const IconData
- calculated_insights → const IconData
- calibration → const IconData
- call → const IconData
- call_coaching → const IconData
- call_history → const IconData
- campaign → const IconData
- campaign_members → const IconData
- cancel_checkout → const IconData
- cancel_file_request → const IconData
- cancel_transfer → const IconData
- canvas → const IconData
- capacity_plan → const IconData
- capslock → const IconData
- captions → const IconData
- care_request_reviewer → const IconData
- carousel → const IconData
- cart → const IconData
- case_change_status → const IconData
- case_comment → const IconData
- case_email → const IconData
- case_icon → const IconData
- case_log_a_call → const IconData
- case_milestone → const IconData
- case_transcript → const IconData
- case_wrap_up → const IconData
- cases → const IconData
- catalog → const IconData
- category → const IconData
- center_align → const IconData
- center_align_text → const IconData
- change_owner → const IconData
- change_record_type → const IconData
- change_request → const IconData
- channel_program_history → const IconData
- channel_program_levels → const IconData
- channel_program_members → const IconData
- channel_programs → const IconData
- chart → const IconData
- chat → const IconData
- check → const IconData
- checkin → const IconData
- checkout → const IconData
- chevrondown → const IconData
- chevronleft → const IconData
- chevronright → const IconData
- chevronup → const IconData
- choice → const IconData
- classic_interface → const IconData
- clear → const IconData
- client → const IconData
- clock → const IconData
- clone → const IconData
- close → const IconData
- cms → const IconData
- coaching → const IconData
- code_playground → const IconData
- code_set → const IconData
- code_set_bundle → const IconData
- collapse_all → const IconData
- collection → const IconData
- collection_alt → const IconData
- collection_variable → const IconData
- color_swatch → const IconData
- comments → const IconData
- company → const IconData
- component_customization → const IconData
- connect_wallet → const IconData
- connected_apps → const IconData
- constant → const IconData
- contact → const IconData
- contact_list → const IconData
- contact_request → const IconData
- contract → const IconData
- contract_alt → const IconData
- contract_doc → const IconData
- contract_line_item → const IconData
- contract_line_outcome → const IconData
- contract_line_outcome_data → const IconData
- contract_payment → const IconData
- copy → const IconData
- copy_to_clipboard → const IconData
- coupon_codes → const IconData
- crossfilter → const IconData
- crypto_category_wallet_group → const IconData
- crypto_product → const IconData
- crypto_product_category_wallet_role → const IconData
- crypto_transaction → const IconData
- crypto_transaction_envelope → const IconData
- crypto_transaction_envelope_change_snapshot → const IconData
- crypto_transaction_envelope_item → const IconData
- crypto_wallet → const IconData
- crypto_wallet_group → const IconData
- crypto_wallet_group_item → const IconData
- csv → const IconData
- currency → const IconData
- currency_input → const IconData
- custom → const IconData
- custom1 → const IconData
- custom2 → const IconData
- custom3 → const IconData
- custom4 → const IconData
- custom5 → const IconData
- custom6 → const IconData
- custom7 → const IconData
- custom8 → const IconData
- custom9 → const IconData
- custom10 → const IconData
- custom11 → const IconData
- custom12 → const IconData
- custom13 → const IconData
- custom14 → const IconData
- custom15 → const IconData
- custom16 → const IconData
- custom17 → const IconData
- custom18 → const IconData
- custom19 → const IconData
- custom20 → const IconData
- custom21 → const IconData
- custom22 → const IconData
- custom23 → const IconData
- custom24 → const IconData
- custom25 → const IconData
- custom26 → const IconData
- custom27 → const IconData
- custom28 → const IconData
- custom29 → const IconData
- custom30 → const IconData
- custom31 → const IconData
- custom32 → const IconData
- custom33 → const IconData
- custom34 → const IconData
- custom35 → const IconData
- custom36 → const IconData
- custom37 → const IconData
- custom38 → const IconData
- custom39 → const IconData
- custom40 → const IconData
- custom41 → const IconData
- custom42 → const IconData
- custom43 → const IconData
- custom44 → const IconData
- custom45 → const IconData
- custom46 → const IconData
- custom47 → const IconData
- custom48 → const IconData
- custom49 → const IconData
- custom50 → const IconData
- custom51 → const IconData
- custom52 → const IconData
- custom53 → const IconData
- custom54 → const IconData
- custom55 → const IconData
- custom56 → const IconData
- custom57 → const IconData
- custom58 → const IconData
- custom59 → const IconData
- custom60 → const IconData
- custom61 → const IconData
- custom62 → const IconData
- custom63 → const IconData
- custom64 → const IconData
- custom65 → const IconData
- custom66 → const IconData
- custom67 → const IconData
- custom68 → const IconData
- custom69 → const IconData
- custom70 → const IconData
- custom71 → const IconData
- custom72 → const IconData
- custom73 → const IconData
- custom74 → const IconData
- custom75 → const IconData
- custom76 → const IconData
- custom77 → const IconData
- custom78 → const IconData
- custom79 → const IconData
- custom80 → const IconData
- custom81 → const IconData
- custom82 → const IconData
- custom83 → const IconData
- custom84 → const IconData
- custom85 → const IconData
- custom86 → const IconData
- custom87 → const IconData
- custom88 → const IconData
- custom89 → const IconData
- custom90 → const IconData
- custom91 → const IconData
- custom92 → const IconData
- custom93 → const IconData
- custom94 → const IconData
- custom95 → const IconData
- custom96 → const IconData
- custom97 → const IconData
- custom98 → const IconData
- custom99 → const IconData
- custom100 → const IconData
- custom101 → const IconData
- custom102 → const IconData
- custom103 → const IconData
- custom104 → const IconData
- custom105 → const IconData
- custom106 → const IconData
- custom107 → const IconData
- custom108 → const IconData
- custom109 → const IconData
- custom110 → const IconData
- custom111 → const IconData
- custom112 → const IconData
- custom113 → const IconData
- custom_apps → const IconData
- custom_component_task → const IconData
- custom_notification → const IconData
- customer → const IconData
- customer_360 → const IconData
- customer_lifecycle_analytics → const IconData
- customer_portal_users → const IconData
- customer_workspace → const IconData
- customers → const IconData
- cut → const IconData
- dash → const IconData
- dashboard → const IconData
- dashboard_component → const IconData
- dashboard_ea → const IconData
- data_integration_hub → const IconData
- data_mapping → const IconData
- data_model → const IconData
- data_streams → const IconData
- data_transforms → const IconData
- database → const IconData
- datadotcom → const IconData
- dataset → const IconData
- date_input → const IconData
- date_time → const IconData
- dayview → const IconData
- decision → const IconData
- default_icon → const IconData
- defer → const IconData
- delegated_account → const IconData
- delete → const IconData
- deprecate → const IconData
- description → const IconData
- desktop → const IconData
- desktop_and_phone → const IconData
- desktop_console → const IconData
- detach → const IconData
- device → const IconData
- dial_in → const IconData
- dialing → const IconData
- diamond → const IconData
- discounts → const IconData
- dislike → const IconData
- display_rich_text → const IconData
- display_text → const IconData
- dock_panel → const IconData
- document → const IconData
- document_reference → const IconData
- down → const IconData
- download → const IconData
- drafts → const IconData
- drag → const IconData
- drag_and_drop → const IconData
- duration_downscale → const IconData
- dynamic_record_choice → const IconData
- edit → const IconData
- edit_form → const IconData
- edit_groups → const IconData
- edit_relationship → const IconData
- education → const IconData
- einstein → const IconData
- einstein_replies → const IconData
- email → const IconData
- email_chatter → const IconData
- email_open → const IconData
- emoji → const IconData
- employee → const IconData
- employee_asset → const IconData
- employee_contact → const IconData
- employee_job → const IconData
- employee_job_position → const IconData
- employee_organization → const IconData
- empty → const IconData
- end_call → const IconData
- end_chat → const IconData
- end_messaging_session → const IconData
- endorsement → const IconData
- engage → const IconData
- enter → const IconData
- entitlement → const IconData
- entitlement_policy → const IconData
- entitlement_process → const IconData
- entitlement_template → const IconData
- entity → const IconData
- entity_milestone → const IconData
- environment_hub → const IconData
- eps → const IconData
- erect_window → const IconData
- error → const IconData
- event → const IconData
- event_ext → const IconData
- events → const IconData
- excel → const IconData
- exe → const IconData
- expand → const IconData
- expand_all → const IconData
- expand_alt → const IconData
- expense → const IconData
- expense_report → const IconData
- expense_report_entry → const IconData
- fallback → const IconData
- favorite → const IconData
- feed → const IconData
- feedback → const IconData
- field_sales → const IconData
- file → const IconData
- filter → const IconData
- filter_criteria → const IconData
- filter_criteria_rule → const IconData
- filterlist → const IconData
- first_non_empty → const IconData
- flash → const IconData
- flow → const IconData
- flow_alt → const IconData
- folder → const IconData
- follow → const IconData
- following → const IconData
- food_and_drink → const IconData
- forecasts → const IconData
- form → const IconData
- formula → const IconData
- forward → const IconData
- forward_up → const IconData
- freeze_column → const IconData
- freeze_user → const IconData
- frozen → const IconData
- fulfillment_order → const IconData
- full_width_view → const IconData
- funding_award_adjustment → const IconData
- funding_requirement → const IconData
- gdoc → const IconData
- gdocs → const IconData
- generic_loading → const IconData
- gform → const IconData
- global_constant → const IconData
- goal → const IconData
- goals → const IconData
- google_news → const IconData
- gpres → const IconData
- graph → const IconData
- group_loading → const IconData
- groups → const IconData
- gsheet → const IconData
- guidance_center → const IconData
- hazmat_equipment → const IconData
- help → const IconData
- help_center → const IconData
- help_doc_ext → const IconData
- hide → const IconData
- hide_mobile → const IconData
- hierarchy → const IconData
- high_velocity_sales → const IconData
- historical_adherence → const IconData
- holiday_operating_hours → const IconData
- home → const IconData
- household → const IconData
- html → const IconData
- http → const IconData
- identifier → const IconData
- identity → const IconData
- image → const IconData
- immunization → const IconData
- in_app_assistant → const IconData
- inbox → const IconData
- incident → const IconData
- incoming_call → const IconData
- individual → const IconData
- info → const IconData
- info_alt → const IconData
- insert_tag_field → const IconData
- insert_template → const IconData
- insights → const IconData
- inspector_panel → const IconData
- instore_locations → const IconData
- investment_account → const IconData
- invocable_action → const IconData
- iot_context → const IconData
- iot_orchestrations → const IconData
- italic → const IconData
- job_family → const IconData
- job_position → const IconData
- job_profile → const IconData
- join_group → const IconData
- jump_to_bottom → const IconData
- jump_to_left → const IconData
- jump_to_right → const IconData
- jump_to_top → const IconData
- justify_text → const IconData
- kanban → const IconData
- key → const IconData
- key_dates → const IconData
- keyboard_dismiss → const IconData
- keynote → const IconData
- keypad → const IconData
- knowledge → const IconData
- knowledge_base → const IconData
- knowledge_smart_link → const IconData
- label → const IconData
- labels → const IconData
- layers → const IconData
- layout → const IconData
- layout_card → const IconData
- layout_overlap → const IconData
- layout_tile → const IconData
- lead → const IconData
- lead_convert → const IconData
- lead_insights → const IconData
- lead_list → const IconData
- learner_program → const IconData
- leave_conference → const IconData
- leave_group → const IconData
- left → const IconData
- left_align → const IconData
- left_align_text → const IconData
- letterhead → const IconData
- level_down → const IconData
- level_up → const IconData
- library_folder → const IconData
- light_bulb → const IconData
- lightning_component → const IconData
- lightning_extension → const IconData
- lightning_inspector → const IconData
- lightning_usage → const IconData
- like → const IconData
- link → const IconData
- linked → const IconData
- list → const IconData
- list_email → const IconData
- listen → const IconData
- live_chat → const IconData
- live_chat_visitor → const IconData
- live_message → const IconData
- location → const IconData
- location_permit → const IconData
- lock → const IconData
- locker_service_api_viewer → const IconData
- locker_service_console → const IconData
- log_a_call → const IconData
- log_event → const IconData
- logging → const IconData
- logout → const IconData
- loop → const IconData
- lower_flag → const IconData
- macros → const IconData
- magicwand → const IconData
- maintenance_asset → const IconData
- maintenance_plan → const IconData
- maintenance_work_rule → const IconData
- manage_perm_sets → const IconData
- map → const IconData
- mark_all_as_read → const IconData
- marketing_actions → const IconData
- matrix → const IconData
- med_rec_recommendation → const IconData
- med_rec_statement_recommendation → const IconData
- medication → const IconData
- medication_dispense → const IconData
- medication_ingredient → const IconData
- medication_reconciliation → const IconData
- medication_statement → const IconData
- meet_content_source → const IconData
- meet_focus_content → const IconData
- meet_focus_equal → const IconData
- meet_focus_presenter → const IconData
- meet_present_panel → const IconData
- merge → const IconData
- merge_field → const IconData
- messaging_conversation → const IconData
- messaging_session → const IconData
- messaging_user → const IconData
- metrics → const IconData
- middle_align → const IconData
- minimize_window → const IconData
- missed_call → const IconData
- money → const IconData
- moneybag → const IconData
- monthlyview → const IconData
- more → const IconData
- move → const IconData
- mp4 → const IconData
- multi_picklist → const IconData
- multi_select_checkbox → const IconData
- muted → const IconData
- network_contract → const IconData
- new_account → const IconData
- new_campaign → const IconData
- new_case → const IconData
- new_child_case → const IconData
- new_contact → const IconData
- new_custom1 → const IconData
- new_custom2 → const IconData
- new_custom3 → const IconData
- new_custom4 → const IconData
- new_custom5 → const IconData
- new_custom6 → const IconData
- new_custom7 → const IconData
- new_custom8 → const IconData
- new_custom9 → const IconData
- new_custom10 → const IconData
- new_custom11 → const IconData
- new_custom12 → const IconData
- new_custom13 → const IconData
- new_custom14 → const IconData
- new_custom15 → const IconData
- new_custom16 → const IconData
- new_custom17 → const IconData
- new_custom18 → const IconData
- new_custom19 → const IconData
- new_custom20 → const IconData
- new_custom21 → const IconData
- new_custom22 → const IconData
- new_custom23 → const IconData
- new_custom24 → const IconData
- new_custom25 → const IconData
- new_custom26 → const IconData
- new_custom27 → const IconData
- new_custom28 → const IconData
- new_custom29 → const IconData
- new_custom30 → const IconData
- new_custom31 → const IconData
- new_custom32 → const IconData
- new_custom33 → const IconData
- new_custom34 → const IconData
- new_custom35 → const IconData
- new_custom36 → const IconData
- new_custom37 → const IconData
- new_custom38 → const IconData
- new_custom39 → const IconData
- new_custom40 → const IconData
- new_custom41 → const IconData
- new_custom42 → const IconData
- new_custom43 → const IconData
- new_custom44 → const IconData
- new_custom45 → const IconData
- new_custom46 → const IconData
- new_custom47 → const IconData
- new_custom48 → const IconData
- new_custom49 → const IconData
- new_custom50 → const IconData
- new_custom51 → const IconData
- new_custom52 → const IconData
- new_custom53 → const IconData
- new_custom54 → const IconData
- new_custom55 → const IconData
- new_custom56 → const IconData
- new_custom57 → const IconData
- new_custom58 → const IconData
- new_custom59 → const IconData
- new_custom60 → const IconData
- new_custom61 → const IconData
- new_custom62 → const IconData
- new_custom63 → const IconData
- new_custom64 → const IconData
- new_custom65 → const IconData
- new_custom66 → const IconData
- new_custom67 → const IconData
- new_custom68 → const IconData
- new_custom69 → const IconData
- new_custom70 → const IconData
- new_custom71 → const IconData
- new_custom72 → const IconData
- new_custom73 → const IconData
- new_custom74 → const IconData
- new_custom75 → const IconData
- new_custom76 → const IconData
- new_custom77 → const IconData
- new_custom78 → const IconData
- new_custom79 → const IconData
- new_custom80 → const IconData
- new_custom81 → const IconData
- new_custom82 → const IconData
- new_custom83 → const IconData
- new_custom84 → const IconData
- new_custom85 → const IconData
- new_custom86 → const IconData
- new_custom87 → const IconData
- new_custom88 → const IconData
- new_custom89 → const IconData
- new_custom90 → const IconData
- new_custom91 → const IconData
- new_custom92 → const IconData
- new_custom93 → const IconData
- new_custom94 → const IconData
- new_custom95 → const IconData
- new_custom96 → const IconData
- new_custom97 → const IconData
- new_custom98 → const IconData
- new_custom99 → const IconData
- new_custom100 → const IconData
- new_direct_message → const IconData
- new_event → const IconData
- new_group → const IconData
- new_icon → const IconData
- new_lead → const IconData
- new_note → const IconData
- new_notebook → const IconData
- new_opportunity → const IconData
- new_person_account → const IconData
- new_task → const IconData
- new_window → const IconData
- news → const IconData
- nft_settings → const IconData
- nft_studio → const IconData
- no_return → const IconData
- note → const IconData
- notebook → const IconData
- notification → const IconData
- number_input → const IconData
- observation_component → const IconData
- office365 → const IconData
- offline → const IconData
- offline_briefcase → const IconData
- offline_cached → const IconData
- omni_channel → const IconData
- omni_supervisor → const IconData
- open → const IconData
- open_folder → const IconData
- opened_folder → const IconData
- operating_hours → const IconData
- opportunity → const IconData
- opportunity_contact_role → const IconData
- opportunity_splits → const IconData
- orchestrator → const IconData
- order_item → const IconData
- orders → const IconData
- org_chart → const IconData
- outbound_call → const IconData
- outcome → const IconData
- output → const IconData
- overflow → const IconData
- overlay → const IconData
- pack → const IconData
- package → const IconData
- package_org → const IconData
- package_org_beta → const IconData
- page → const IconData
- pages → const IconData
- palette → const IconData
- partner_fund_allocation → const IconData
- partner_fund_claim → const IconData
- partner_fund_request → const IconData
- partner_marketing_budget → const IconData
- partners → const IconData
- password → const IconData
- password_unlock → const IconData
- past_chat → const IconData
- paste → const IconData
- patient_medication_dosage → const IconData
- pause → const IconData
- pause_alt → const IconData
- payment_gateway → const IconData
- pdf → const IconData
- pdf_ext → const IconData
- people → const IconData
- percent → const IconData
- performance → const IconData
- person_account → const IconData
- person_language → const IconData
- person_name → const IconData
- phone_landscape → const IconData
- phone_portrait → const IconData
- photo → const IconData
- picklist → const IconData
- picklist_choice → const IconData
- picklist_type → const IconData
- pin → const IconData
- pinned → const IconData
- planning_poker → const IconData
- planogram → const IconData
- play → const IconData
- podcast_webinar → const IconData
- poll → const IconData
- pop_in → const IconData
- portal → const IconData
- portal_roles → const IconData
- portal_roles_and_subordinates → const IconData
- post → const IconData
- power → const IconData
- ppt → const IconData
- practitioner_role → const IconData
- preview → const IconData
- price_book_entries → const IconData
- price_books → const IconData
- pricebook → const IconData
- pricing_workspace → const IconData
- print → const IconData
- priority → const IconData
- problem → const IconData
- procedure → const IconData
- procedure_detail → const IconData
- process → const IconData
- process_exception → const IconData
- product → const IconData
- product_consumed → const IconData
- product_consumed_state → const IconData
- product_item → const IconData
- product_item_transaction → const IconData
- product_quantity_rules → const IconData
- product_request → const IconData
- product_request_line_item → const IconData
- product_required → const IconData
- product_service_campaign → const IconData
- product_service_campaign_item → const IconData
- product_transfer → const IconData
- product_transfer_state → const IconData
- product_warranty_term → const IconData
- product_workspace → const IconData
- products → const IconData
- profile → const IconData
- promotion_segments → const IconData
- promotion_tiers → const IconData
- promotions → const IconData
- promotions_workspace → const IconData
- prompt → const IconData
- prompt_edit → const IconData
- propagation_policy → const IconData
- proposition → const IconData
- psd → const IconData
- push → const IconData
- puzzle → const IconData
- qualifications → const IconData
- question → const IconData
- question_best → const IconData
- question_feed → const IconData
- question_mark → const IconData
- question_post_action → const IconData
- questions_and_answers → const IconData
- queue → const IconData
- quick_text → const IconData
- quip → const IconData
- quip_doc → const IconData
- quip_sheet → const IconData
- quip_slide → const IconData
- quotation_marks → const IconData
- quote → const IconData
- quotes → const IconData
- rating → const IconData
- read_receipts → const IconData
- reassign → const IconData
- recall → const IconData
- recent → const IconData
- recipe → const IconData
- record → const IconData
- record_alt → const IconData
- record_create → const IconData
- record_delete → const IconData
- record_lookup → const IconData
- record_signature_task → const IconData
- record_update → const IconData
- recurring_exception → const IconData
- recycle_bin → const IconData
- recycle_bin_empty → const IconData
- recycle_bin_full → const IconData
- redo → const IconData
- refresh → const IconData
- reject → const IconData
- relate → const IconData
- relationship → const IconData
- reminder → const IconData
- remove → const IconData
- remove_formatting → const IconData
- remove_link → const IconData
- remove_relationship → const IconData
- replace → const IconData
- reply → const IconData
- reply_all → const IconData
- reply_text → const IconData
- report → const IconData
- report_issue → const IconData
- report_type → const IconData
- reset_password → const IconData
- resource_absence → const IconData
- resource_capacity → const IconData
- resource_preference → const IconData
- resource_skill → const IconData
- resource_territory → const IconData
- restriction_policy → const IconData
- retail_execution → const IconData
- return_order → const IconData
- return_order_line_item → const IconData
- retweet → const IconData
- reward → const IconData
- ribbon → const IconData
- richtextbulletedlist → const IconData
- richtextindent → const IconData
- richtextnumberedlist → const IconData
- richtextoutdent → const IconData
- right → const IconData
- right_align → const IconData
- right_align_text → const IconData
- rotate → const IconData
- routing_offline → const IconData
- rows → const IconData
- rtc_presence → const IconData
- rtf → const IconData
- rules → const IconData
- sales_cadence → const IconData
- sales_cadence_target → const IconData
- sales_channel → const IconData
- sales_path → const IconData
- sales_value → const IconData
- salesforce1 → const IconData
- salesforce_cms → const IconData
- salesforce_page → const IconData
- save → const IconData
- scan → const IconData
- scan_card → const IconData
- scan_disabled → const IconData
- scan_enabled → const IconData
- schedule_objective → const IconData
- scheduling_constraint → const IconData
- scheduling_policy → const IconData
- screen → const IconData
- script → const IconData
- search → const IconData
- section → const IconData
- segments → const IconData
- selling_model → const IconData
- send → const IconData
- send_log → const IconData
- sentiment_negative → const IconData
- sentiment_neutral → const IconData
- serialized_product → const IconData
- serialized_product_transaction → const IconData
- service_appointment → const IconData
- service_appointment_capacity_usage → const IconData
- service_contract → const IconData
- service_crew → const IconData
- service_crew_member → const IconData
- service_report → const IconData
- service_request → const IconData
- service_request_detail → const IconData
- service_resource → const IconData
- service_territory → const IconData
- service_territory_location → const IconData
- service_territory_member → const IconData
- service_territory_policy → const IconData
- settings → const IconData
- setup → const IconData
- setup_assistant_guide → const IconData
- setup_modal → const IconData
- shield → const IconData
- shift → const IconData
- shift_pattern → const IconData
- shift_pattern_entry → const IconData
- shift_preference → const IconData
- shift_scheduling_operation → const IconData
- shift_template → const IconData
- shift_type → const IconData
- shift_ui → const IconData
- shipment → const IconData
- shopping_bag → const IconData
- shortcuts → const IconData
- side_list → const IconData
- signature → const IconData
- signpost → const IconData
- skill → const IconData
- skill_entity → const IconData
- skill_requirement → const IconData
- skip → const IconData
- skip_back → const IconData
- skip_forward → const IconData
- slack → const IconData
- slack_conversations → const IconData
- slide → const IconData
- slider → const IconData
- smiley_and_people → const IconData
- sms → const IconData
- snippet → const IconData
- snippet_alt → const IconData
- snippets → const IconData
- sobject → const IconData
- sobject_collection → const IconData
- solution → const IconData
- sort → const IconData
- sort_policy → const IconData
- sossession → const IconData
- spacer → const IconData
- spinner → const IconData
- stage → const IconData
- stage_collection → const IconData
- standard_objects → const IconData
- steps → const IconData
- stop → const IconData
- store → const IconData
- store_group → const IconData
- story → const IconData
- strategy → const IconData
- strikethrough → const IconData
- stypi → const IconData
- submit_for_approval → const IconData
- success → const IconData
- summary → const IconData
- summarydetail → const IconData
- survey → const IconData
- swarm_request → const IconData
- swarm_session → const IconData
- switch_icon → const IconData
- symbols → const IconData
- sync_icon → const IconData
- system_and_global_variable → const IconData
- table → const IconData
- table_settings → const IconData
- tableau → const IconData
- tablet_landscape → const IconData
- tablet_portrait → const IconData
- tabset → const IconData
- talent_development → const IconData
- target → const IconData
- target_mode → const IconData
- task → const IconData
- task2 → const IconData
- tax_policy → const IconData
- tax_rate → const IconData
- tax_treatment → const IconData
- team_member → const IconData
- template → const IconData
- text → const IconData
- text_background_color → const IconData
- text_color → const IconData
- text_template → const IconData
- textarea → const IconData
- textbox → const IconData
- thanks → const IconData
- thanks_loading → const IconData
- threedots → const IconData
- threedots_vertical → const IconData
- thunder → const IconData
- tile_card_list → const IconData
- timesheet → const IconData
- timesheet_entry → const IconData
- timeslot → const IconData
- today → const IconData
- toggle → const IconData
- toggle_panel_bottom → const IconData
- toggle_panel_left → const IconData
- toggle_panel_right → const IconData
- toggle_panel_top → const IconData
- tollways → const IconData
- top_align → const IconData
- topic → const IconData
- topic2 → const IconData
- touch_action → const IconData
- tour → const IconData
- tour_check → const IconData
- tracker → const IconData
- trail → const IconData
- trailblazer_ext → const IconData
- trailhead → const IconData
- trailhead_alt → const IconData
- trailhead_ext → const IconData
- transparent → const IconData
- transport_bicycle → const IconData
- transport_heavy_truck → const IconData
- transport_light_truck → const IconData
- transport_walking → const IconData
- travel_and_places → const IconData
- travel_mode → const IconData
- trending → const IconData
- truck → const IconData
- turn_off_notifications → const IconData
- txt → const IconData
- type → const IconData
- type_tool → const IconData
- undelete → const IconData
- undeprecate → const IconData
- underline → const IconData
- undo → const IconData
- unified_health_score → const IconData
- unknown → const IconData
- unlinked → const IconData
- unlock → const IconData
- unmatched → const IconData
- unmuted → const IconData
- up → const IconData
- update → const IconData
- update_status → const IconData
- upload → const IconData
- user → const IconData
- user_activation → const IconData
- user_role → const IconData
- variable → const IconData
- variation_attribute_setup → const IconData
- variation_products → const IconData
- video → const IconData
- video_off → const IconData
- view_relationship → const IconData
- visio → const IconData
- visit_templates → const IconData
- visits → const IconData
- visualforce_page → const IconData
- voice_call → const IconData
- voicemail_drop → const IconData
- volume_high → const IconData
- volume_low → const IconData
- volume_off → const IconData
- waits → const IconData
- warning → const IconData
- warranty_term → const IconData
- watchlist → const IconData
- water → const IconData
- web_link → const IconData
- webcart → const IconData
- webex → const IconData
- weeklyview → const IconData
- wellness → const IconData
- wifi → const IconData
- word → const IconData
- work_capacity_limit → const IconData
- work_capacity_usage → const IconData
- work_contract → const IconData
- work_forecast → const IconData
- work_order → const IconData
- work_order_item → const IconData
- work_order_type → const IconData
- work_plan → const IconData
- work_plan_rule → const IconData
- work_plan_template → const IconData
- work_plan_template_entry → const IconData
- work_queue → const IconData
- work_step → const IconData
- work_step_template → const IconData
- work_type → const IconData
- work_type_group → const IconData
- workforce_engagement → const IconData
- world → const IconData
- xml → const IconData
- your_account → const IconData
- yubi_key → const IconData
- zip → const IconData
- zoomin → const IconData
- zoomout → const IconData